import { trpc } from "../../trpc";
import {
  calendarExitPriceChartData,
  span,
  openDTE,
  exitDTE,
  lookbackPeriodEnd,
  lookbackPeriodStart,
  similarCalendarPriceChartData,
  stockPriceChartData,
  moniness,
  moninessRadius,
  underlying,
} from "./state";

function debounce(func, wait) {
  let timeout;
  return function () {
    const context = this;
    const args = arguments;
    clearTimeout(timeout);
    timeout = setTimeout(() => func.apply(context, args), wait);
  };
}
function throttle(func, limit) {
  let inThrottle;
  return function () {
    const context = this;
    const args = arguments;
    if (!inThrottle) {
      func.apply(context, args);
      inThrottle = true;
      setTimeout(() => (inThrottle = false), limit);
    }
  };
}

export const refreshStockPriceChartData = throttle(() => {
  stockPriceChartData.value = [];
  trpc.StockPriceChart.getChartData
    .query({
      underlying: underlying.value,
      lookbackPeriodStart: lookbackPeriodStart.value,
      lookbackPeriodEnd: lookbackPeriodEnd.value,
    })
    .then((getChartDataResponse) => {
      stockPriceChartData.value = getChartDataResponse;
    });
}, 400);
export const refreshSimilarCalendarPriceChartData = throttle(() => {
  similarCalendarPriceChartData.value = [];
  trpc.SimilarCalendarPriceChart.getChartData
    .query({
      underlying: underlying.value,
      daysToFrontExpiration: openDTE.value,
      daysBetweenFrontAndBackExpiration: span.value,
      strikePercentageFromUnderlyingPriceRangeMin:
        (moniness.value - moninessRadius.value) / 100,
      strikePercentageFromUnderlyingPriceRangeMax:
        (moniness.value + moninessRadius.value) / 100,
      lookbackPeriodStart: lookbackPeriodStart.value,
      lookbackPeriodEnd: lookbackPeriodEnd.value,
    })
    .then((getChartDataResponse) => {
      similarCalendarPriceChartData.value = getChartDataResponse;
    });
}, 400);
export const refreshcalendarExitPriceChartData = throttle(() => {
  calendarExitPriceChartData.value = [];
  trpc.CalendarExitPriceChart.getChartData
    .query({
      underlying: underlying.value,
      daysToFrontExpiration: exitDTE.value,
      daysBetweenFrontAndBackExpiration: span.value,
      lookbackPeriodStart: lookbackPeriodStart.value,
      lookbackPeriodEnd: lookbackPeriodEnd.value,
    })
    .then((getChartDataResponse) => {
      calendarExitPriceChartData.value = getChartDataResponse;
    });
}, 400);
